@@ -39,10 +39,16 @@ class J2SwiftLoader(jinja2.BaseLoader):
     only the absolute path relative to the container root is searched.
     """
 
-    def __init__(self, swift, container, searchpath):
+    def __init__(self, swift, container, searchpath=None):
         self.swift = swift
         self.container = container
-        self.searchpath = [searchpath]
+        if searchpath is not None:
+            if isinstance(searchpath, six.string_types):
+                self.searchpath = [searchpath]
+            else:
+                self.searchpath = list(searchpath)
+        else:
+            self.searchpath = []
         # Always search the absolute path from the root of the swift container
         if '' not in self.searchpath:
             self.searchpath.append('')
@@ -93,9 +99,15 @@ class ProcessTemplatesAction(base.TripleOAction):
     def __init__(self, container=constants.DEFAULT_CONTAINER_NAME):
         super(ProcessTemplatesAction, self).__init__()
         self.container = container
-        self.role_data = None
 
-    def _j2_render_and_put(self, j2_template, j2_data, yaml_f, swift):
+    def _j2_render_and_put(self,
+                           j2_template,
+                           j2_data,
+                           outfile_name=None,
+                           context=None):
+        swift = self.get_object_client(context)
+        yaml_f = outfile_name or j2_template.replace('.j2.yaml', '.yaml')
+
         # Search for templates relative to the current template path first
         template_base = os.path.dirname(yaml_f)
         j2_loader = J2SwiftLoader(swift, self.container, template_base)
@@ -182,10 +194,6 @@ class ProcessTemplatesAction(base.TripleOAction):
             # Allow no networks defined in network_data
             if network_data is None:
                 network_data = []
-            # Set internal network index key for each network, network
-            # resources are created with a tag tripleo_net_idx
-            for idx, _ in enumerate(network_data):
-                network_data[idx].update({'idx': idx})
         except swiftexceptions.ClientException:
             # Until t-h-t contains network_data.yaml we tolerate a missing file
             LOG.warning("No %s file found, ignoring"
@@ -238,9 +246,8 @@ class ProcessTemplatesAction(base.TripleOAction):
                 LOG.info("skipping %s network: network is disabled." %
                          n.get('name'))
 
-        self.cache_delete(context,
-                          self.container,
-                          "tripleo.parameters.get")
+        plan_utils.cache_delete(swift, self.container,
+                                "tripleo.parameters.get")
 
         for f in [f.get('name') for f in container_files[1]]:
             # We do three templating passes here:
@@ -279,7 +286,7 @@ class ProcessTemplatesAction(base.TripleOAction):
                             self._j2_render_and_put(j2_template,
                                                     j2_data,
                                                     out_f_path,
-                                                    swift)
+                                                    context=context)
                         else:
                             # Backwards compatibility with templates
                             # that specify {{role}} vs {{role.name}}
@@ -288,12 +295,12 @@ class ProcessTemplatesAction(base.TripleOAction):
                             self._j2_render_and_put(j2_template,
                                                     j2_data,
                                                     out_f_path,
-                                                    swift)
+                                                    context=context)
                     else:
                         LOG.info("Skipping rendering of %s, defined in %s" %
                                  (out_f_path, j2_excl_data))
 
-            elif f.endswith('.network.j2.yaml'):
+            elif (f.endswith('.network.j2.yaml')):
                 LOG.info("jinja2 rendering network template %s" % f)
                 j2_template = swiftutils.get_object_string(swift,
                                                            self.container,
@@ -315,7 +322,7 @@ class ProcessTemplatesAction(base.TripleOAction):
                         self._j2_render_and_put(j2_template,
                                                 j2_data,
                                                 out_f_path,
-                                                swift)
+                                                context=context)
                     else:
                         LOG.info("Skipping rendering of %s, defined in %s" %
                                  (out_f_path, j2_excl_data))
@@ -330,8 +337,7 @@ class ProcessTemplatesAction(base.TripleOAction):
                 self._j2_render_and_put(j2_template,
                                         j2_data,
                                         out_f,
-                                        swift)
-        return role_data
+                                        context=context)
 
     def run(self, context):
         error_text = None
@@ -353,7 +359,7 @@ class ProcessTemplatesAction(base.TripleOAction):
             # not found in swift, but if they are found and an exception
             # occurs during processing, that exception will cause the
             # ProcessTemplatesAction to return an error result.
-            self.role_data = self._process_custom_roles(context)
+            self._process_custom_roles(context)
         except Exception as err:
             LOG.exception("Error occurred while processing custom roles.")
             return actions.Result(error=six.text_type(err))
