@@ -14,12 +14,10 @@
 #
 
 import collections
-import errno
 import hashlib
 import json
 import os
 import requests
-import six
 import shutil
 
 from oslo_log import log as logging
@@ -53,25 +51,14 @@ TYPE_KEYS = (
 TYPE_MAP_EXTENSION = '.type-map'
 
 
-def skip_if_exists(f):
-    @six.wraps(f)
-    def wrapper(*args, **kwargs):
-        try:
-            return f(*args, **kwargs)
-        except OSError as e:
-            # Handle race for the already existing entity
-            if e.errno == errno.EEXIST:
-                pass
-            else:
-                raise e
-    return wrapper
-
-
-@skip_if_exists
 def make_dir(path):
     if os.path.exists(path):
         return
-    os.makedirs(path, 0o775)
+    try:
+        os.makedirs(path, 0o775)
+    except os.error:
+        # Handle race for directory already existing
+        pass
 
 
 def image_tag_from_url(image_url):
@@ -90,7 +77,6 @@ def image_tag_from_url(image_url):
     return image, tag
 
 
-@skip_if_exists
 def export_stream(target_url, layer, layer_stream, verify_digest=True):
     image, _ = image_tag_from_url(target_url)
     digest = layer['digest']
@@ -110,9 +96,7 @@ def export_stream(target_url, layer, layer_stream, verify_digest=True):
                       (image, blob_path))
 
     try:
-        fd = os.open(blob_path, os.O_WRONLY | os.O_CREAT)
-        os.fchmod(fd, 0o0644)
-        with os.fdopen(fd, 'wb') as f:
+        with open(blob_path, 'wb') as f:
             count = 0
             for chunk in layer_stream:
                 count += 1
@@ -130,13 +114,6 @@ def export_stream(target_url, layer, layer_stream, verify_digest=True):
         LOG.error(memory_error)
         remove_layer(image, blob_path)
         raise MemoryError(memory_error)
-    except requests.exceptions.HTTPError as e:
-        # catch http errors seperately as those can be retried in
-        # the image uploader
-        http_error = '[{}] HTTP error: {}'.format(image, str(e))
-        LOG.error(http_error)
-        remove_layer(image, blob_path)
-        raise
     except Exception as e:
         write_error = '[{}] Write Failure: {}'.format(image, str(e))
         LOG.error(write_error)
@@ -183,7 +160,6 @@ def export_stream(target_url, layer, layer_stream, verify_digest=True):
     return (layer_digest, blob_path)
 
 
-@skip_if_exists
 def layer_cross_link(layer, image, blob_path, target_image_url):
     target_image, _ = image_tag_from_url(target_image_url)
     target_dir_path = os.path.join(
@@ -329,8 +305,8 @@ def parse_type_map_file(type_map_path):
     content_type = None
     type_map = {}
     with open(type_map_path, 'r') as f:
-        for x in f:
-            line = x[:-1]
+        for l in f:
+            line = l[:-1]
             if not line:
                 if uri and content_type:
                     type_map[content_type] = uri
@@ -382,17 +358,12 @@ def build_catalog():
     catalog_entries = []
     LOG.debug('Rebuilding %s' % catalog_path)
     images_path = os.path.join(IMAGE_EXPORT_DIR, 'v2')
-    metadata_set = set(['blobs', 'manifests', 'tags'])
 
     for namespace in os.listdir(images_path):
         namespace_path = os.path.join(images_path, namespace)
         if not os.path.isdir(namespace_path):
             continue
-        contents_set = set(os.listdir(namespace_path))
-        # handle containers with no namespaces
-        if metadata_set.issubset(contents_set):
-            catalog_entries.append(namespace)
-        for image in list(contents_set - metadata_set):
+        for image in os.listdir(namespace_path):
             catalog_entries.append('%s/%s' % (namespace, image))
 
     catalog = {'repositories': catalog_entries}
