@@ -341,8 +341,24 @@ class BaseImageUploader(object):
         LOG.info('Playbook: \n%s' % yaml.safe_dump(
             playbook, default_flow_style=False))
         work_dir = tempfile.mkdtemp(prefix='tripleo-modify-image-playbook-')
+        log_name = 'tripleo-container-image-prepare-ansible.log'
         try:
-            action = ansible.AnsiblePlaybookAction(
+            for handler in LOG.logger.root.handlers:
+                if hasattr(handler, 'baseFilename'):
+                    if os.path.isfile(handler.baseFilename):
+                        log_f = os.path.join(
+                            os.path.dirname(handler.baseFilename),
+                            log_name
+                        )
+                        break
+            else:
+                raise OSError('Log output is not a file.')
+        except (AttributeError, OSError):
+            tmp_dir = tempfile.gettempdir()
+            log_f = os.path.join(tmp_dir, log_name)
+        try:
+            LOG.info('Ansible action starting')
+            ansible.AnsiblePlaybookAction(
                 playbook=playbook,
                 work_dir=work_dir,
                 verbosity=1,
@@ -350,20 +366,26 @@ class BaseImageUploader(object):
                 override_ansible_cfg=(
                     "[defaults]\n"
                     "stdout_callback=yaml\n"
+                    "log_path=%s\n" % log_f
+                )
+            ).run(None)
+        except processutils.ProcessExecutionError as e:
+            LOG.error(
+                '%s\n'
+                'Error running playbook in directory: %s\n'
+                'Playbook log information can be reviewed here: %s' % (
+                    e.stdout,
+                    work_dir,
+                    log_f
                 )
             )
-            result = action.run(None)
-            log_path = result.get('log_path')
-            if log_path and os.path.isfile(log_path):
-                with open(log_path) as f:
-                    for line in f:
-                        LOG.info(line.rstrip())
-            shutil.rmtree(work_dir)
-        except processutils.ProcessExecutionError as e:
-            LOG.error('%s\nError running playbook in directory: %s'
-                      % (e.stdout, work_dir))
             raise ImageUploaderException(
-                'Modifying image %s failed' % target_image)
+                'Modifying image %s failed' % target_image
+            )
+        else:
+            LOG.info('Ansible action completed')
+        finally:
+            shutil.rmtree(work_dir)
 
     @classmethod
     def _images_match(cls, image1, image2, session1=None):
@@ -568,10 +590,11 @@ class BaseImageUploader(object):
             mirror = cls.mirrors[netloc]
             return '%sv2%s' % (mirror, path)
         else:
-            if not cls.is_insecure_registry(registry_host=netloc):
-                scheme = 'https'
-            else:
+            if (cls.is_insecure_registry(registry_host=netloc) and
+                    netloc not in cls.no_verify_registries):
                 scheme = 'http'
+            else:
+                scheme = 'https'
             if netloc == 'docker.io':
                 netloc = 'registry-1.docker.io'
             return '%s://%s/v2%s' % (scheme, netloc, path)
@@ -656,7 +679,10 @@ class BaseImageUploader(object):
         name = '%s%s' % (image_url.netloc, image)
         created = config['created']
         docker_version = config.get('docker_version', '')
-        labels = config['config']['Labels']
+        labels = config['config'].get('Labels', {})
+        # NOTE: labels can be null
+        if labels is None:
+            labels = {}
         architecture = config['architecture']
         image_os = config['os']
 
@@ -768,7 +794,7 @@ class BaseImageUploader(object):
                 tag_label = tag_from_label.format(**labels)
             except ValueError as e:
                 raise ImageUploaderException(e)
-            except KeyError as e:
+            except (KeyError, TypeError) as e:
                 if fallback_tag:
                     tag_label = fallback_tag
                 else:
@@ -820,8 +846,16 @@ class BaseImageUploader(object):
                            fallback_tag=None, username=None, password=None):
         image_url = self._image_to_url(image)
         self.is_insecure_registry(registry_host=image_url.netloc)
-        session = self.authenticate(
-            image_url, username=username, password=password)
+        try:
+            session = self.authenticate(
+                image_url, username=username, password=password)
+        except requests.exceptions.HTTPError as e:
+            if e.response.status_code == 401:
+                raise ImageUploaderException(
+                    'Unable to authenticate. This may indicate '
+                    'missing registry credentials or the provided '
+                    'container or namespace does not exist. %s' % e)
+            raise
 
         i = self._inspect(image_url, session)
         return self._discover_tag_from_inspect(i, image, tag_from_label,
@@ -833,8 +867,16 @@ class BaseImageUploader(object):
         for image in images:
             url = self._image_to_url(image)
             self.is_insecure_registry(registry_host=url.netloc)
-            session = self.authenticate(
-                url, username=username, password=password)
+            try:
+                session = self.authenticate(
+                    url, username=username, password=password)
+            except requests.exceptions.HTTPError as e:
+                if e.response.status_code == 401:
+                    raise ImageUploaderException(
+                        'Unable to authenticate. This may indicate '
+                        'missing registry credentials or the provided '
+                        'container or namespace does not exist. %s' % e)
+                raise
             image_labels = self._image_labels(
                 url, session=session)
             if set(labels).issubset(set(image_labels)):
@@ -1071,14 +1113,17 @@ class SkopeoImageUploader(BaseImageUploader):
         cmd.append(target)
         LOG.info('Running %s' % ' '.join(cmd))
         env = os.environ.copy()
-        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
-                                   universal_newlines=True)
+        try:
+            process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
+                                       universal_newlines=True)
 
-        out, err = process.communicate()
-        LOG.info(out)
-        if process.returncode != 0:
-            raise ImageUploaderException('Error copying image:\n%s\n%s' %
-                                         (' '.join(cmd), err))
+            out, err = process.communicate()
+            LOG.info(out)
+            if process.returncode != 0:
+                raise ImageUploaderException('Error copying image:\n%s\n%s' %
+                                             (' '.join(cmd), err))
+        except KeyboardInterrupt:
+            raise Exception('Action interrupted with ctrl+c')
         return out
 
     def _delete(self, image_url, session=None):
@@ -1092,14 +1137,17 @@ class SkopeoImageUploader(BaseImageUploader):
         cmd.append(image)
         LOG.info('Running %s' % ' '.join(cmd))
         env = os.environ.copy()
-        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
-                                   universal_newlines=True)
+        try:
+            process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
+                                       universal_newlines=True)
 
-        out, err = process.communicate()
-        LOG.info(out.decode('utf-8'))
-        if process.returncode != 0:
-            raise ImageUploaderException('Error deleting image:\n%s\n%s' %
-                                         (' '.join(cmd), err))
+            out, err = process.communicate()
+            LOG.info(out.decode('utf-8'))
+            if process.returncode != 0:
+                raise ImageUploaderException('Error deleting image:\n%s\n%s' %
+                                             (' '.join(cmd), err))
+        except KeyboardInterrupt:
+            raise Exception('Action interrupted with ctrl+c')
         return out
 
     def cleanup(self, local_images):
@@ -1184,6 +1232,19 @@ class PythonImageUploader(BaseImageUploader):
 
     @classmethod
     def _global_view_proxy(cls, value=None, forget=False):
+        """Represent the global view for mixed multi-workers concurrent access
+
+        Depending on worker's context target the corresponding shared data
+        structures (global view) for the requested value add/remove
+        operation. Also keep that global view always consolidated for all of
+        the supported MP/MT worker types. Threads will share common data via
+        its common class namespace in the threads-safe standard dictionary.
+        Processes will use multiprocess synchronization primitives stored in
+        the global lock context.
+
+        :param: value: Shared data to track in the global view
+        :param: forget: Defines either to add or remove the shared data
+        """
         if not cls.lock:
             LOG.warning('No lock information provided for value %s' % value)
             return
@@ -1209,6 +1270,19 @@ class PythonImageUploader(BaseImageUploader):
     @classmethod
     def _track_uploaded_layers(cls, layer, known_path=None, image_ref=None,
                                forget=False, scope='remote'):
+        """Track an image layer info in the global view
+
+        Adds or removes layer info to/from the global view shared among
+        all workers of all supported types (MP/MT). An image layer hash and
+        scope pair provide a unique one-way entry tracked in the global view.
+        The layer info being forgotten will be untracked by any existing scope.
+
+        :param: layer: A container image layer hash to track in the global view
+        :param: known_path: Known URL or local path for the tracked layer
+        :param: image_ref: Name of the image cross-referencing tracked layer
+        :param: forget: Defines either to add or remove the tracked layer info
+        :param: scope: Specifies remote or local type of the tracked image
+        """
         if forget:
             LOG.debug('Untracking processed layer %s for any scope' % layer)
             cls._global_view_proxy(value=layer, forget=True)
@@ -1244,11 +1318,19 @@ class PythonImageUploader(BaseImageUploader):
 
         target_username, target_password = self.credentials_for_registry(
             t.target_image_url.netloc)
-        target_session = self.authenticate(
-            t.target_image_url,
-            username=target_username,
-            password=target_password
-        )
+        try:
+            target_session = self.authenticate(
+                t.target_image_url,
+                username=target_username,
+                password=target_password
+            )
+        except requests.exceptions.HTTPError as e:
+            if e.response.status_code == 401:
+                raise ImageUploaderException(
+                    'Unable to authenticate. This may indicate '
+                    'missing registry credentials or the provided '
+                    'container or namespace does not exist. %s' % e)
+            raise
 
         try:
             self._detect_target_export(t.target_image_url, target_session)
@@ -1304,11 +1386,19 @@ class PythonImageUploader(BaseImageUploader):
 
         source_username, source_password = self.credentials_for_registry(
             t.source_image_url.netloc)
-        source_session = self.authenticate(
-            t.source_image_url,
-            username=source_username,
-            password=source_password
-        )
+        try:
+            source_session = self.authenticate(
+                t.source_image_url,
+                username=source_username,
+                password=source_password
+            )
+        except requests.exceptions.HTTPError as e:
+            if e.response.status_code == 401:
+                raise ImageUploaderException(
+                    'Unable to authenticate. This may indicate '
+                    'missing registry credentials or the provided '
+                    'container or namespace does not exist. %s' % e)
+            raise
 
         source_layers = []
         manifests_str = []
@@ -1787,25 +1877,28 @@ class PythonImageUploader(BaseImageUploader):
         cmd.append(pull_source)
         LOG.info('Pulling %s' % pull_source)
         LOG.info('Running %s' % ' '.join(cmd))
-        process = subprocess.Popen(
-            cmd,
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-            universal_newlines=True,
-            close_fds=True
-        )
-        out, err = process.communicate()
-        if process.returncode != 0:
-            error_msg = (
-                'Pulling image failed: cmd "{}", stdout "{}",'
-                ' stderr "{}"'.format(
-                    ' '.join(cmd),
-                    out,
-                    err
-                )
+        try:
+            process = subprocess.Popen(
+                cmd,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                universal_newlines=True,
+                close_fds=True
             )
-            LOG.error(error_msg)
-            raise ImageUploaderException(error_msg)
+            out, err = process.communicate()
+            if process.returncode != 0:
+                error_msg = (
+                    'Pulling image failed: cmd "{}", stdout "{}",'
+                    ' stderr "{}"'.format(
+                        ' '.join(cmd),
+                        out,
+                        err
+                    )
+                )
+                LOG.error(error_msg)
+                raise ImageUploaderException(error_msg)
+        except KeyboardInterrupt:
+            raise Exception('Action interrupted with ctrl+c')
         return out
 
     @classmethod
@@ -1866,19 +1959,22 @@ class PythonImageUploader(BaseImageUploader):
             '--compress'
         ]
         LOG.debug(' '.join(cmd))
-        p = subprocess.Popen(cmd, stdout=subprocess.PIPE)
+        try:
+            p = subprocess.Popen(cmd, stdout=subprocess.PIPE)
 
-        chunk_size = 2 ** 20
+            chunk_size = 2 ** 20
 
-        while True:
-            data = p.stdout.read(chunk_size)
-            if not data:
-                break
-            calc_digest.update(data)
-            yield data
-        p.wait()
-        if p.returncode != 0:
-            raise ImageUploaderException('Extracting layer failed')
+            while True:
+                data = p.stdout.read(chunk_size)
+                if not data:
+                    break
+                calc_digest.update(data)
+                yield data
+            p.wait()
+            if p.returncode != 0:
+                raise ImageUploaderException('Extracting layer failed')
+        except KeyboardInterrupt:
+            raise Exception('Action interrupted with ctrl+c')
 
     @classmethod
     @tenacity.retry(  # Retry up to 5 times with jittered exponential backoff
@@ -2114,7 +2210,10 @@ class PythonImageUploader(BaseImageUploader):
         i, _ = cls._image_tag_from_url(image_url)
         digest = image['digest']
         created = image['created']
-        labels = config['config']['Labels']
+        labels = config['config'].get('Labels', {})
+        # NOTE: labels can be null
+        if labels is None:
+            labels = {}
         architecture = config['architecture']
         image_os = config['os']
         return {
@@ -2148,13 +2247,17 @@ class PythonImageUploader(BaseImageUploader):
         cmd = ['buildah', 'rmi', image_url.path]
         LOG.info('Running %s' % ' '.join(cmd))
         env = os.environ.copy()
-        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
-                                   universal_newlines=True)
+        try:
+            process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
+                                       universal_newlines=True)
 
-        out, err = process.communicate()
-        LOG.info(out)
-        if process.returncode != 0:
-            LOG.warning('Error deleting image:\n%s\n%s' % (' '.join(cmd), err))
+            out, err = process.communicate()
+            LOG.info(out)
+            if process.returncode != 0:
+                LOG.warning('Error deleting image:\n%s\n%s' %
+                            (' '.join(cmd), err))
+        except KeyboardInterrupt:
+            raise Exception('Action interrupted with ctrl+c')
         return out
 
     def cleanup(self, local_images):
@@ -2258,8 +2361,16 @@ def discover_tag_from_inspect(args):
     self, image, tag_from_label = args
     image_url = self._image_to_url(image)
     username, password = self.credentials_for_registry(image_url.netloc)
-    session = self.authenticate(
-        image_url, username=username, password=password)
+    try:
+        session = self.authenticate(
+            image_url, username=username, password=password)
+    except requests.exceptions.HTTPError as e:
+        if e.response.status_code == 401:
+            raise ImageUploaderException(
+                'Unable to authenticate. This may indicate '
+                'missing registry credentials or the provided '
+                'container or namespace does not exist. %s' % e)
+        raise
     i = self._inspect(image_url, session=session)
     session.close()
     if ':' in image_url.path:
