@@ -48,18 +48,11 @@ def init_prepare_defaults(defaults_file):
 
     global CONTAINER_IMAGES_DEFAULTS
     CONTAINER_IMAGES_DEFAULTS = CONTAINER_IMAGE_PREPARE_PARAM[0]['set']
-    # Handle CentOS8 since we shipped train with py2 support, we need
-    # to still support it while handling the namespace switch for
-    # CentOS8 but only for the defaults
-    if ((CONTAINER_IMAGES_DEFAULTS['namespace'] == 'docker.io/tripleotrain'
-         or CONTAINER_IMAGES_DEFAULTS['namespace'] == 'quay.io/tripleotrain')
-            and sys.version_info.major > 2):
-        CONTAINER_IMAGES_DEFAULTS['namespace'] += 'centos8'
 
 
 DEFAULT_TEMPLATE_FILE = os.path.join(sys.prefix, 'share', 'tripleo-common',
                                      'container-images',
-                                     'tripleo_containers.yaml.j2')
+                                     'overcloud_containers.yaml.j2')
 
 DEFAULT_PREPARE_FILE = os.path.join(sys.prefix, 'share', 'tripleo-common',
                                     'container-images',
@@ -107,11 +100,18 @@ def build_service_filter(environment, roles_data):
         return None
     enabled_services = get_enabled_services(environment, roles_data)
     resource_registry = environment.get('resource_registry')
-    if resource_registry:
-        for service in enabled_services.copy():
-            env_path = resource_registry.get(service)
-            if env_path == 'OS::Heat::None':
-                enabled_services.remove(service)
+    if not resource_registry:
+        # no way to tell which services are non-containerized, so
+        # filter by enabled services
+        return enabled_services
+
+    for service, env_path in environment.get('resource_registry', {}).items():
+        if service not in enabled_services:
+            continue
+        if env_path == 'OS::Heat::None':
+            enabled_services.remove(service)
+        if '/puppet/services' in env_path:
+            enabled_services.remove(service)
 
     return enabled_services
 
@@ -122,16 +122,12 @@ def set_neutron_driver(pd, mapping_args):
     :param pd: Parameter defaults from the environment
     :param mapping_args: Dict to set neutron_driver value on
     """
-    if mapping_args.get('neutron_driver'):
-        return
     if not pd or 'NeutronMechanismDrivers' not in pd:
         # we should set default neutron driver
         mapping_args['neutron_driver'] = 'ovn'
         return
     nmd = pd['NeutronMechanismDrivers']
-    if 'opendaylight_v2' in nmd:
-        mapping_args['neutron_driver'] = 'odl'
-    elif 'ovn' in nmd:
+    if 'ovn' in nmd:
         mapping_args['neutron_driver'] = 'ovn'
     else:
         mapping_args['neutron_driver'] = 'other'
@@ -191,16 +187,9 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
         modify_role = cip_entry.get('modify_role')
         modify_vars = cip_entry.get('modify_vars')
         modify_only_with_labels = cip_entry.get('modify_only_with_labels')
-        modify_only_with_source = cip_entry.get('modify_only_with_source')
         modify_append_tag = cip_entry.get('modify_append_tag',
                                           time.strftime(
                                               '-modified-%Y%m%d%H%M%S'))
-
-        # do not use tag_from_label if a tag is specified in the set
-        tag_from_label = None
-        if not mapping_args.get('tag'):
-            tag_from_label = cip_entry.get('tag_from_label')
-
         if multi_arch and 'multi_arch' in cip_entry:
             # individual entry sets multi_arch,
             # so set global multi_arch to False
@@ -215,12 +204,11 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
             mapping_args=mapping_args,
             output_env_file='image_params',
             output_images_file='upload_data',
-            tag_from_label=tag_from_label,
+            tag_from_label=cip_entry.get('tag_from_label'),
             append_tag=modify_append_tag,
             modify_role=modify_role,
             modify_vars=modify_vars,
             modify_only_with_labels=modify_only_with_labels,
-            modify_only_with_source=modify_only_with_source,
             mirrors=mirrors,
             registry_credentials=creds,
             multi_arch=multi_arch,
@@ -228,13 +216,14 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
         )
         env_params.update(prepare_data['image_params'])
 
-        if not dry_run and (push_destination or pull_source or modify_role):
+        if push_destination or pull_source or modify_role:
             with tempfile.NamedTemporaryFile(mode='w') as f:
                 yaml.safe_dump({
                     'container_images': prepare_data['upload_data']
                 }, f)
                 uploader = image_uploader.ImageUploadManager(
                     [f.name],
+                    dry_run=dry_run,
                     cleanup=cleanup,
                     mirrors=mirrors,
                     registry_credentials=creds,
@@ -262,7 +251,6 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
                              output_images_file=None, tag_from_label=None,
                              append_tag=None, modify_role=None,
                              modify_vars=None, modify_only_with_labels=None,
-                             modify_only_with_source=None,
                              mirrors=None, registry_credentials=None,
                              multi_arch=False, lock=None):
     """Perform container image preparation
@@ -290,9 +278,6 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
     :param modify_vars: dict of variables to pass to modify_role
     :param modify_only_with_labels: only modify the container images with the
                                     given labels
-    :param modify_only_with_source: only modify the container images from a
-                                    image_source in the tripleo-common service
-                                    to container mapping (e.g. kolla/tripleo)
     :param mirrors: dict of registry netloc values to mirror urls
     :param registry_credentials: dict of registry netloc values to
                                  authentication credentials for that registry.
@@ -343,15 +328,10 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
     )
     uploader = manager.uploader('python')
     images = [i.get('imagename', '') for i in result]
-    # set a flag to record whether the default tag is used or not. the
-    # logic here is that if the tag key is not already in mapping then it
-    # wil be added during the template render, so default_tag is set to
-    # True.
-    default_tag = 'tag' not in mapping_args
 
     if tag_from_label:
         image_version_tags = uploader.discover_image_tags(
-            images, tag_from_label, default_tag)
+            images, tag_from_label)
         for entry in result:
             imagename = entry.get('imagename', '')
             image_no_tag = imagename.rpartition(':')[0]
@@ -359,27 +339,18 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
                 entry['imagename'] = '%s:%s' % (
                     image_no_tag, image_version_tags[image_no_tag])
 
-    images_with_labels = []
     if modify_only_with_labels:
         images_with_labels = uploader.filter_images_with_labels(
             images, modify_only_with_labels)
 
-    images_with_source = []
-    if modify_only_with_source:
-        images_with_source = [i.get('imagename') for i in result
-                              if i.get('image_source', '')
-                              in modify_only_with_source]
-
     params = {}
     modify_append_tag = append_tag
     for entry in result:
         imagename = entry.get('imagename', '')
         append_tag = ''
         if modify_role and (
-                (not modify_only_with_labels
-                    and not modify_only_with_source) or
-                (imagename in images_with_labels or
-                    imagename in images_with_source)):
+                (not modify_only_with_labels) or
+                imagename in images_with_labels):
             entry['modify_role'] = modify_role
             if modify_append_tag:
                 entry['modify_append_tag'] = modify_append_tag
@@ -465,16 +436,9 @@ class KollaImageBuilder(base.BaseImageManager):
         hyphenated appropriately.
         '''
         mapping = dict(kwargs)
-
         if CONTAINER_IMAGES_DEFAULTS is None:
             return
         for k, v in CONTAINER_IMAGES_DEFAULTS.items():
-            # Handle CentOS8 since we shipped train with py2 support, we need
-            # to still support it while handling the namespace switch for
-            # CentOS8 but only for the defaults
-            if (k == 'namespace' and v == 'docker.io/tripleotrain'
-                    and sys.version_info.major > 2):
-                v += 'centos8'
             mapping.setdefault(k, v)
         np = mapping['name_prefix']
         if np and not np.endswith('-'):
@@ -537,15 +501,13 @@ class KollaImageBuilder(base.BaseImageManager):
         container_images.sort(key=lambda i: i.get('imagename'))
         for i in container_images:
             # Do not attempt to build containers that are not from kolla or
-            # tripleo, or are in our exclude list
-            allowed_source_list = ['kolla', 'tripleo']
-            if i.get('image_source', '') not in allowed_source_list:
+            # are in our exclude list
+            if not i.get('image_source', '') == 'kolla':
                 continue
             image = self.imagename_to_regex(i.get('imagename'))
             # Make sure the image was properly parsed and not purposely skipped
             if image and image not in excludes:
-                # NOTE(mgoddard): Use a full string match.
-                cmd.append("^%s$" % image)
+                cmd.append(image)
 
         if template_only:
             # build the dep list cmd line
