@@ -29,61 +29,18 @@ from tripleo_common.actions import ansible
 from tripleo_common.tests import base
 
 
-class AnsibleActionTest(base.TestCase):
-
-    def setUp(self):
-        super(AnsibleActionTest, self).setUp()
-
-        self.hosts = "127.0.0.2"
-        self.module = "foo"
-        self.remote_user = 'fido'
-        self.become = True
-        self.become_user = 'root'
-        self.ctx = mock.MagicMock()
-
-    @mock.patch("tripleo_common.actions.ansible.write_default_ansible_cfg")
-    @mock.patch("oslo_concurrency.processutils.execute")
-    def test_run(self, mock_execute, mock_write_cfg):
-
-        mock_execute.return_value = ('', '')
-
-        action = ansible.AnsibleAction(
-            hosts=self.hosts, module=self.module, remote_user=self.remote_user,
-            become=self.become, become_user=self.become_user)
-        ansible_config_path = os.path.join(action.work_dir, 'ansible.cfg')
-        mock_write_cfg.return_value = ansible_config_path
-
-        action.run(self.ctx)
-
-        env = {
-            'HOME': action.work_dir,
-            'ANSIBLE_LOCAL_TEMP': action.work_dir,
-            'ANSIBLE_CONFIG': ansible_config_path
-        }
-
-        mock_write_cfg.assert_called_once_with(action.work_dir,
-                                               self.remote_user,
-                                               ssh_private_key=None)
-
-        mock_execute.assert_called_once_with(
-            'ansible', self.hosts, '-vvvvv', '--module-name', self.module,
-            '--become', '--become-user', self.become_user, env_variables=env,
-            cwd=action.work_dir, log_errors=processutils.LogErrors.ALL
-        )
-
-
 class AnsiblePlaybookActionTest(base.TestCase):
 
     def setUp(self):
         super(AnsiblePlaybookActionTest, self).setUp()
 
         self.playbook = "myplaybook"
-        self.limit_hosts = "compute0,compute1"
+        self.limit_hosts = None
         self.remote_user = 'fido'
         self.become = True
         self.become_user = 'root'
         self.extra_vars = {"var1": True, "var2": 0}
-        self.verbosity = 2
+        self.verbosity = 1
         self.ctx = mock.MagicMock()
         self.max_message_size = 1024
 
@@ -97,7 +54,8 @@ class AnsiblePlaybookActionTest(base.TestCase):
             playbook=self.playbook, limit_hosts=self.limit_hosts,
             remote_user=self.remote_user, become=self.become,
             become_user=self.become_user, extra_vars=self.extra_vars,
-            verbosity=self.verbosity)
+            verbosity=self.verbosity, config_download_args=['--check',
+                                                            '--diff'])
         ansible_config_path = os.path.join(action.work_dir, 'ansible.cfg')
         mock_write_cfg.return_value = ansible_config_path
 
@@ -113,100 +71,16 @@ class AnsiblePlaybookActionTest(base.TestCase):
             'HOME': action.work_dir,
             'ANSIBLE_LOCAL_TEMP': action.work_dir,
             'ANSIBLE_CONFIG': ansible_config_path,
-            'ANSIBLE_CALLBACK_WHITELIST':
-                'tripleo_dense,tripleo_profile_tasks,tripleo_states',
-            'ANSIBLE_STDOUT_CALLBACK': 'tripleo_dense',
-            'PROFILE_TASKS_TASK_OUTPUT_LIMIT': '20',
+            'ANSIBLE_CALLBACK_WHITELIST': 'profile_tasks',
+            'PROFILE_TASKS_TASK_OUTPUT_LIMIT': '0',
         }
         python_version = sys.version_info.major
         ansible_playbook_cmd = 'ansible-playbook-{}'.format(python_version)
         mock_execute.assert_called_once_with(
-            ansible_playbook_cmd, '-v', pb, '--limit', self.limit_hosts,
-            '--become', '--become-user',
+            ansible_playbook_cmd, '-v', pb, '--become',
+            '--become-user',
             self.become_user, '--extra-vars', json.dumps(self.extra_vars),
-            env_variables=env, cwd=action.work_dir,
-            log_errors=processutils.LogErrors.ALL)
-
-    @mock.patch("tripleo_common.actions.ansible.write_default_ansible_cfg")
-    @mock.patch("oslo_concurrency.processutils.execute")
-    def test_run_with_limit(self, mock_execute, mock_write_cfg):
-
-        mock_execute.return_value = ('', '')
-
-        action = ansible.AnsiblePlaybookAction(
-            playbook=self.playbook, limit_hosts=['compute35'],
-            blacklisted_hostnames=['compute21'],
-            remote_user=self.remote_user, become=self.become,
-            become_user=self.become_user, extra_vars=self.extra_vars,
-            verbosity=self.verbosity)
-        ansible_config_path = os.path.join(action.work_dir, 'ansible.cfg')
-        mock_write_cfg.return_value = ansible_config_path
-
-        action.run(self.ctx)
-
-        mock_write_cfg.assert_called_once_with(action.work_dir,
-                                               self.remote_user,
-                                               ssh_private_key=None,
-                                               override_ansible_cfg=None)
-
-        pb = os.path.join(action.work_dir, 'playbook.yaml')
-        env = {
-            'HOME': action.work_dir,
-            'ANSIBLE_LOCAL_TEMP': action.work_dir,
-            'ANSIBLE_CONFIG': ansible_config_path,
-            'ANSIBLE_CALLBACK_WHITELIST':
-                'tripleo_dense,tripleo_profile_tasks,tripleo_states',
-            'ANSIBLE_STDOUT_CALLBACK': 'tripleo_dense',
-            'PROFILE_TASKS_TASK_OUTPUT_LIMIT': '20',
-        }
-        python_version = sys.version_info.major
-        ansible_playbook_cmd = 'ansible-playbook-{}'.format(python_version)
-        mock_execute.assert_called_once_with(
-            ansible_playbook_cmd, '-v', pb, '--limit', "['compute35']",
-            '--become', '--become-user',
-            self.become_user, '--extra-vars', json.dumps(self.extra_vars),
-            env_variables=env, cwd=action.work_dir,
-            log_errors=processutils.LogErrors.ALL)
-
-    @mock.patch("tripleo_common.actions.ansible.write_default_ansible_cfg")
-    @mock.patch("oslo_concurrency.processutils.execute")
-    def test_run_with_blacklist(self, mock_execute, mock_write_cfg):
-
-        mock_execute.return_value = ('', '')
-
-        action = ansible.AnsiblePlaybookAction(
-            playbook=self.playbook, limit_hosts=None,
-            blacklisted_hostnames=['compute21'],
-            remote_user=self.remote_user, become=self.become,
-            become_user=self.become_user, extra_vars=self.extra_vars,
-            verbosity=self.verbosity)
-        ansible_config_path = os.path.join(action.work_dir, 'ansible.cfg')
-        mock_write_cfg.return_value = ansible_config_path
-
-        action.run(self.ctx)
-
-        mock_write_cfg.assert_called_once_with(action.work_dir,
-                                               self.remote_user,
-                                               ssh_private_key=None,
-                                               override_ansible_cfg=None)
-
-        pb = os.path.join(action.work_dir, 'playbook.yaml')
-        env = {
-            'HOME': action.work_dir,
-            'ANSIBLE_LOCAL_TEMP': action.work_dir,
-            'ANSIBLE_CONFIG': ansible_config_path,
-            'ANSIBLE_CALLBACK_WHITELIST':
-                'tripleo_dense,tripleo_profile_tasks,tripleo_states',
-            'ANSIBLE_STDOUT_CALLBACK': 'tripleo_dense',
-            'PROFILE_TASKS_TASK_OUTPUT_LIMIT': '20',
-        }
-        python_version = sys.version_info.major
-        ansible_playbook_cmd = 'ansible-playbook-{}'.format(python_version)
-        mock_execute.assert_called_once_with(
-            ansible_playbook_cmd, '-v', pb, '--limit', '!compute21',
-            '--become', '--become-user',
-            self.become_user, '--extra-vars', json.dumps(self.extra_vars),
-            env_variables=env, cwd=action.work_dir,
+            '--check', '--diff', env_variables=env, cwd=action.work_dir,
             log_errors=processutils.LogErrors.ALL)
 
     @mock.patch("tripleo_common.actions.ansible.write_default_ansible_cfg")
@@ -388,4 +262,4 @@ class CopyConfigFileTest(base.TestCase):
             ansible_cfg = configparser.ConfigParser()
             ansible_cfg.read(resulting_ansible_config)
 
-            self.assertEqual('16', ansible_cfg.get('defaults', 'forks'))
+            self.assertEqual('40', ansible_cfg.get('defaults', 'forks'))
