@@ -154,15 +154,14 @@ _EXISTING_PASSWORDS = {
         'public_key': 'public_key'
         },
     'LibvirtTLSPassword': 'xCdt9yeamKz8Fb6EGba9u82XU',
-    'OpenDaylightPassword': 'abc487gfh017rmviuq75jdiw7',
 }
 
 
 class GetParametersActionTest(base.TestCase):
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_set')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_get')
     @mock.patch('heatclient.common.template_utils.'
                 'process_multiple_environments_and_files')
@@ -211,12 +210,12 @@ class GetParametersActionTest(base.TestCase):
             template={'heat_template_version': '2016-04-30'},
         )
         mock_cache_get.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get"
         )
         mock_cache_set.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get",
             {'heat_resource_tree': {}, 'environment_parameters': None}
@@ -225,7 +224,7 @@ class GetParametersActionTest(base.TestCase):
 
 class ResetParametersActionTest(base.TestCase):
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_delete')
     @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     def test_run(self, mock_get_object_client, mock_cache):
@@ -259,7 +258,7 @@ class ResetParametersActionTest(base.TestCase):
             mock_env_reset
         )
         mock_cache.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get"
         )
@@ -272,7 +271,7 @@ class UpdateParametersActionTest(base.TestCase):
                 'process_multiple_environments_and_files')
     @mock.patch('heatclient.common.template_utils.'
                 'get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_set')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'get_object_client')
@@ -384,7 +383,7 @@ class UpdateParametersActionTest(base.TestCase):
         )
 
         mock_cache.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get",
             expected_value
@@ -395,7 +394,7 @@ class UpdateParametersActionTest(base.TestCase):
                 'process_multiple_environments_and_files')
     @mock.patch('heatclient.common.template_utils.'
                 'get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_set')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'get_object_client')
@@ -482,7 +481,7 @@ class UpdateParametersActionTest(base.TestCase):
         )
 
         mock_cache.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get",
             {'environment_parameters': None, 'heat_resource_tree': {}}
@@ -495,7 +494,7 @@ class UpdateRoleParametersActionTest(base.TestCase):
                 'process_multiple_environments_and_files')
     @mock.patch('heatclient.common.template_utils.'
                 'get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_set')
     @mock.patch('tripleo_common.utils.parameters.set_count_and_flavor_params')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
@@ -584,7 +583,7 @@ class UpdateRoleParametersActionTest(base.TestCase):
         )
 
         mock_cache.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcast",
             "tripleo.parameters.get",
             {'environment_parameters': None, 'heat_resource_tree': {}}
@@ -593,7 +592,7 @@ class UpdateRoleParametersActionTest(base.TestCase):
 
 class GeneratePasswordsActionTest(base.TestCase):
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_delete')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'get_orchestration_client')
@@ -646,12 +645,12 @@ class GeneratePasswordsActionTest(base.TestCase):
                                     'existing_value')
 
         mock_cache.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get"
         )
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_delete')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'get_orchestration_client')
@@ -703,12 +702,12 @@ class GeneratePasswordsActionTest(base.TestCase):
         # ensure old passwords used and no new generation
         self.assertEqual(_EXISTING_PASSWORDS, result)
         mock_cache.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get"
         )
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_delete')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'get_orchestration_client')
@@ -774,12 +773,12 @@ class GeneratePasswordsActionTest(base.TestCase):
         # ensure new passwords have been generated
         self.assertNotEqual(_EXISTING_PASSWORDS, result)
         mock_cache.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get"
         )
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_delete')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'get_orchestration_client')
@@ -855,12 +854,12 @@ class GeneratePasswordsActionTest(base.TestCase):
                 self.assertEqual(_EXISTING_PASSWORDS[name], result[name])
 
         mock_cache.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get"
         )
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_delete')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
                 'get_orchestration_client')
@@ -918,7 +917,7 @@ class GeneratePasswordsActionTest(base.TestCase):
         # ensure old passwords used and no new generation
         self.assertEqual(existing_passwords, result)
         mock_cache.assert_called_once_with(
-            mock_ctx,
+            swift,
             "overcloud",
             "tripleo.parameters.get"
         )
@@ -1171,9 +1170,9 @@ class GenerateFencingParametersActionTestCase(base.TestCase):
 
 class GetFlattenedParametersActionTest(base.TestCase):
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_set')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_get')
     @mock.patch('heatclient.common.template_utils.'
                 'process_multiple_environments_and_files')
@@ -1229,9 +1228,9 @@ class GetFlattenedParametersActionTest(base.TestCase):
         )
         self.assertEqual(result, expected_value)
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_set')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_get')
     @mock.patch('uuid.uuid4', side_effect=['1', '2'])
     @mock.patch('heatclient.common.template_utils.'
@@ -1440,9 +1439,9 @@ class RotateFernetKeysActionTest(base.TestCase):
 
 class GetNetworkConfigActionTest(base.TestCase):
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_set')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_get')
     @mock.patch('heatclient.common.template_utils.'
                 'process_multiple_environments_and_files')
@@ -1502,9 +1501,154 @@ class GetNetworkConfigActionTest(base.TestCase):
             stack_name='overcloud-TEMP',
         )
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_set')
+    @mock.patch('tripleo_common.utils.plan.'
+                'cache_get')
+    @mock.patch('heatclient.common.template_utils.'
+                'process_multiple_environments_and_files')
+    @mock.patch('heatclient.common.template_utils.get_template_contents')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_orchestration_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_workflow_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    def test_run_valid_network_config_with_no_interface_routes_inputs(
+            self, mock_get_object_client, mock_get_workflow_client,
+            mock_get_orchestration_client, mock_get_template_contents,
+            mock_process_multiple_environments_and_files,
+            mock_cache_get,
+            mock_cache_set):
+
+        mock_ctx = mock.MagicMock()
+        swift = mock.MagicMock(url="http://test.com")
+        mock_env = yaml.safe_dump({
+            'temp_environment': 'temp_environment',
+            'template': 'template',
+            'environments': [{u'path': u'environments/test.yaml'}]
+        }, default_flow_style=False)
+        swift.get_object.side_effect = (
+            ({}, mock_env),
+            swiftexceptions.ClientException('atest2'),
+            ({}, mock_env)
+        )
+        mock_get_object_client.return_value = swift
+
+        mock_get_template_contents.return_value = ({}, {
+            'heat_template_version': '2016-04-30',
+            'resources': {'ComputeGroupVars': {'properties': {
+                'value': {'role_networks': ['InternalApi', 'Storage']}
+                }
+            }}
+        })
+        mock_process_multiple_environments_and_files.return_value = (
+            {}, {'parameter_defaults': {}})
+
+        mock_heat = mock.MagicMock()
+        mock_heat.stacks.preview.return_value = mock.Mock(resources=[{
+            "resource_identity": {"stack_name": "overcloud-TEMP-Compute-0"},
+            "resource_name": "OsNetConfigImpl",
+            "properties": {"config": "echo \'{\"network_config\": {}}\'"
+                           " > /etc/os-net-config/config.json"}
+            }])
+
+        mock_get_orchestration_client.return_value = mock_heat
+
+        mock_cache_get.return_value = None
+        expected = {"network_config": {}}
+        # Test
+        action = parameters.GetNetworkConfigAction(container='overcloud',
+                                                   role_name='Compute')
+        result = action.run(mock_ctx)
+        self.assertEqual(expected, result)
+        mock_heat.stacks.preview.assert_called_once_with(
+            environment={'parameter_defaults': {
+                'InternalApiInterfaceRoutes': [[]],
+                'StorageInterfaceRoutes': [[]]}},
+            files={},
+            template={'heat_template_version': '2016-04-30',
+                      'resources': {'ComputeGroupVars': {
+                          'properties': {'value': {
+                              'role_networks': ['InternalApi',
+                                                'Storage']}}}}},
+            stack_name='overcloud-TEMP',
+        )
+
+    @mock.patch('tripleo_common.utils.plan.'
+                'cache_set')
+    @mock.patch('tripleo_common.utils.plan.'
+                'cache_get')
+    @mock.patch('heatclient.common.template_utils.'
+                'process_multiple_environments_and_files')
+    @mock.patch('heatclient.common.template_utils.get_template_contents')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_orchestration_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.'
+                'get_workflow_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    def test_run_valid_network_config_with_interface_routes_inputs(
+            self, mock_get_object_client, mock_get_workflow_client,
+            mock_get_orchestration_client, mock_get_template_contents,
+            mock_process_multiple_environments_and_files,
+            mock_cache_get,
+            mock_cache_set):
+
+        mock_ctx = mock.MagicMock()
+        swift = mock.MagicMock(url="http://test.com")
+        mock_env = yaml.safe_dump({
+            'temp_environment': 'temp_environment',
+            'template': 'template',
+            'environments': [{u'path': u'environments/test.yaml'}]
+        }, default_flow_style=False)
+        swift.get_object.side_effect = (
+            ({}, mock_env),
+            swiftexceptions.ClientException('atest2'),
+            ({}, mock_env)
+        )
+        mock_get_object_client.return_value = swift
+
+        mock_get_template_contents.return_value = ({}, {
+            'heat_template_version': '2016-04-30',
+            'resources': {'ComputeGroupVars': {'properties': {
+                'value': {'role_networks': ['InternalApi', 'Storage']}}}}
+        })
+        mock_process_multiple_environments_and_files.return_value = (
+            {}, {'parameter_defaults': {
+                'InternalApiInterfaceRoutes': ['test1'],
+                'StorageInterfaceRoutes': ['test2']}})
+
+        mock_heat = mock.MagicMock()
+        mock_heat.stacks.preview.return_value = mock.Mock(resources=[{
+            "resource_identity": {"stack_name": "overcloud-TEMP-Compute-0"},
+            "resource_name": "OsNetConfigImpl",
+            "properties": {"config": "echo \'{\"network_config\": {}}\'"
+                           " > /etc/os-net-config/config.json"}
+            }])
+
+        mock_get_orchestration_client.return_value = mock_heat
+
+        mock_cache_get.return_value = None
+        expected = {"network_config": {}}
+        # Test
+        action = parameters.GetNetworkConfigAction(container='overcloud',
+                                                   role_name='Compute')
+        result = action.run(mock_ctx)
+        self.assertEqual(expected, result)
+        mock_heat.stacks.preview.assert_called_once_with(
+            environment={'parameter_defaults': {
+                'InternalApiInterfaceRoutes': ['test1'],
+                'StorageInterfaceRoutes': ['test2']}},
+            files={},
+            template={'heat_template_version': '2016-04-30',
+                      'resources': {'ComputeGroupVars': {'properties': {
+                          'value': {'role_networks': ['InternalApi',
+                                                      'Storage']}}}}},
+            stack_name='overcloud-TEMP',
+        )
+
+    @mock.patch('tripleo_common.utils.plan.'
+                'cache_set')
+    @mock.patch('tripleo_common.utils.plan.'
                 'cache_get')
     @mock.patch('heatclient.common.template_utils.'
                 'process_multiple_environments_and_files')
