@@ -394,6 +394,25 @@ class TestBaseImageUploader(base.TestCase):
             'docker.io/t/foo:b',
             'rdo_version')
 
+        # handle auth issues
+        mock_401 = mock.Mock()
+        mock_401.status_code = 401
+        mock_401_except = requests.exceptions.HTTPError(response=mock_401)
+        mock_404 = mock.Mock()
+        mock_404.status_code = 404
+        mock_404_except = requests.exceptions.HTTPError(response=mock_404)
+        mock_auth.side_effect = [mock_401_except, mock_404_except]
+        self.assertRaises(
+            ImageUploaderException,
+            image_uploader.discover_tag_from_inspect,
+            (self.uploader, 'docker.io/t/foo', 'rdo_version')
+        )
+        self.assertRaises(
+            requests.exceptions.HTTPError,
+            image_uploader.discover_tag_from_inspect,
+            (self.uploader, 'docker.io/t/foo', 'rdo_version')
+        )
+
     @mock.patch('tripleo_common.image.image_uploader.'
                 'BaseImageUploader.authenticate')
     @mock.patch('tripleo_common.image.image_uploader.'
@@ -480,6 +499,25 @@ class TestBaseImageUploader(base.TestCase):
             (self.uploader, 'docker.io/t/foo', 'rdo_version')
         )
 
+        # handle auth issues
+        mock_401 = mock.Mock()
+        mock_401.status_code = 401
+        mock_401_except = requests.exceptions.HTTPError(response=mock_401)
+        mock_404 = mock.Mock()
+        mock_404.status_code = 404
+        mock_404_except = requests.exceptions.HTTPError(response=mock_404)
+        mock_auth.side_effect = [mock_401_except, mock_404_except]
+        self.assertRaises(
+            ImageUploaderException,
+            image_uploader.discover_tag_from_inspect,
+            (self.uploader, 'docker.io/t/foo', 'rdo_version')
+        )
+        self.assertRaises(
+            requests.exceptions.HTTPError,
+            image_uploader.discover_tag_from_inspect,
+            (self.uploader, 'docker.io/t/foo', 'rdo_version')
+        )
+
     @mock.patch('concurrent.futures.ThreadPoolExecutor')
     def test_discover_image_tags(self, mock_pool):
         mock_map = mock.Mock()
@@ -587,6 +625,7 @@ class TestBaseImageUploader(base.TestCase):
         build = image_uploader.BaseImageUploader._build_url
         insecure_reg = image_uploader.BaseImageUploader.insecure_registries
         secure_reg = image_uploader.BaseImageUploader.secure_registries
+        no_verify_reg = image_uploader.BaseImageUploader.no_verify_registries
         mirrors = image_uploader.BaseImageUploader.mirrors
         # fix urls
         self.assertEqual(
@@ -605,6 +644,13 @@ class TestBaseImageUploader(base.TestCase):
             'https://192.0.2.1:8787/v2/t/nova-api/tags/list',
             build(url3, '/t/nova-api/tags/list')
         )
+        # "no verify" registries are insecure but still use https
+        secure_reg.remove('192.0.2.1:8787')
+        no_verify_reg.add('192.0.2.1:8787')
+        self.assertEqual(
+            'https://192.0.2.1:8787/v2/t/nova-api/tags/list',
+            build(url3, '/t/nova-api/tags/list')
+        )
 
         # test mirrors
         mirrors['docker.io'] = 'http://192.0.2.2:8081/registry-1.docker/'
@@ -1068,6 +1114,8 @@ class TestSkopeoImageUploader(base.TestCase):
             override_ansible_cfg=(
                 "[defaults]\n"
                 "stdout_callback=yaml\n"
+                "log_path=%s/tripleo-container-image-prepare-ansible.log\n"
+                % os.path.dirname(logfile.name)
             )
         )
 
@@ -2348,6 +2396,49 @@ class TestPythonImageUploader(base.TestCase):
             self.uploader._inspect(url)
         )
 
+    @mock.patch('tripleo_common.image.image_uploader.'
+                'PythonImageUploader._image_manifest_config')
+    def test_inspect_no_labels(self, _image_manifest_config):
+        url = urlparse('containers-storage:/t/nova-api:latest')
+        config = {
+            'config': {},
+            'architecture': 'x86_64',
+            'os': 'linux'
+        }
+        _image_manifest_config.return_value = (
+            {
+                'id': 'cccc',
+                'digest': 'sha256:ccccc',
+                'names': ['192.168.2.1:5000/t/nova-api:latest'],
+                'created': '2018-10-02T11:13:45.567533229Z'
+            }, {
+                'config': {
+                    'digest': 'sha256:1234',
+                },
+                'layers': [
+                    {'digest': 'sha256:aaa'},
+                    {'digest': 'sha256:bbb'},
+                    {'digest': 'sha256:ccc'}
+                ],
+            },
+            json.dumps(config)
+        )
+
+        self.assertEqual(
+            {
+                'Name': '/t/nova-api',
+                'Architecture': 'x86_64',
+                'Created': '2018-10-02T11:13:45.567533229Z',
+                'Digest': 'sha256:ccccc',
+                'DockerVersion': '',
+                'Labels': {},
+                'Layers': ['sha256:aaa', 'sha256:bbb', 'sha256:ccc'],
+                'Os': 'linux',
+                'RepoTags': []
+            },
+            self.uploader._inspect(url)
+        )
+
     @mock.patch('os.environ')
     @mock.patch('subprocess.Popen')
     def test_delete(self, mock_popen, mock_environ):
