@@ -23,13 +23,11 @@ import warnings
 import yaml
 
 import jinja2
-from oslo_utils import uuidutils
 
 from tripleo_common import constants
 from tripleo_common.utils.safe_import import git
 
-warnings.filterwarnings('once', category=DeprecationWarning)
-warnings.filterwarnings('once', category=UserWarning)
+warnings.filterwarnings('once')
 
 
 class Config(object):
@@ -117,43 +115,28 @@ class Config(object):
         return os.fdopen(
             os.open(path, os.O_WRONLY | os.O_CREAT | os.O_TRUNC, 0o600), 'w')
 
-    def _write_tasks_per_step(self, tasks, filepath, step, strict=False):
+    def _write_tasks_per_step(self, tasks, role, filepath, step):
 
-        def step_in_task(task, step, strict):
+        def step_in_task(task, step):
             whenexpr = task.get('when', None)
             if whenexpr is None:
-                if not strict:
-                    # If no step is defined, it will be executed for all
-                    # steps if strict is false
-                    return True
-                else:
-                    # We only want the task with the step defined.
-                    return False
+                # If no step is defined, it will be executed for all
+                # steps.
+                return True
             if not isinstance(whenexpr, list):
                 whenexpr = [whenexpr]
-
-            # Filter out boolean value and remove blanks
-            flatten_when = "".join([re.sub(r'\s+', '', x)
-                                    for x in whenexpr
-                                    if isinstance(x, six.string_types)])
-            # make \|int optional incase forgotten; use only step digit:
-            # ()'s around step|int are also optional
-            steps_found = re.findall(r'\(?step(?:\|int)?\)?==(\d+)',
-                                     flatten_when)
-            if steps_found:
-                if str(step) in steps_found:
-                    return True
-                else:
-                    return False
-
-            # No step found
-            if strict:
-                return False
+            for w in whenexpr:
+                # make \|int optional incase forgotten; use only step digit:
+                # ()'s around step|int are also optional
+                match = re.search(r'\(?step(\|int)?\)? == ([0-9]+)$', "%s" % w)
+                if match:
+                    if match.group(2) == str(step):
+                        return True
+                    else:
+                        return False
             return True
 
-        tasks_per_step = [task for task in tasks if step_in_task(task,
-                                                                 step,
-                                                                 strict)]
+        tasks_per_step = [task for task in tasks if step_in_task(task, step)]
         with self._open_file(filepath) as conf_file:
             yaml.safe_dump(tasks_per_step, conf_file, default_flow_style=False)
         return tasks_per_step
@@ -223,12 +206,6 @@ class Config(object):
         network_config = self.get_network_config_data(stack)
         for server, config in network_config.items():
             if server in server_roles:
-                if config is None or not uuidutils.is_uuid_like(config):
-                    # config should be a valid heat resource id
-                    err_msg = ('Invalid network config for role %s. Please '
-                               'check the network config templates used.' %
-                               server_roles[server])
-                    raise ValueError(err_msg)
                 server_deployment_dir = os.path.join(
                     config_dir, server_roles[server], server)
                 self._mkdir(server_deployment_dir)
@@ -267,23 +244,25 @@ class Config(object):
                     with self._open_file(filepath) as param_config:
                         param_config.write(json.dumps(role[config]))
                 elif config == 'ansible_group_vars':
-                    role_config = role[config].copy()
-                    role_config.update(role_group_vars[role_name])
-                    role_group_vars[role_name] = role_config
+                    # NOTE(aschultz): ansible group vars are for specific role
+                    # services so we merge them in with the others so they
+                    # end up in the role vars. This means the last var
+                    # definition wins and will override them all.
+                    if role_name not in role_group_vars:
+                        role_group_vars[role_name] = {}
+                    role_group_vars[role_name].update(role[config])
                 else:
                     # NOTE(emilien): Move this condition to the
                     # upper level once THT is adapted for all tasks to be
                     # run per step.
                     # We include it here to allow the CI to pass until THT
                     # changed is not merged.
-                    if config in constants.PER_STEP_TASKS.keys():
-                        for i in range(len(constants.PER_STEP_TASKS[config])):
+                    if config in constants.PER_STEP_TASKS:
+                        for i in range(constants.DEFAULT_STEPS_MAX):
                             filepath = os.path.join(role_path, '%s_step%s.yaml'
                                                     % (config, i))
-                            self._write_tasks_per_step(
-                                role[config],
-                                filepath,
-                                i, constants.PER_STEP_TASKS[config][i])
+                            self._write_tasks_per_step(role[config], role_name,
+                                                       filepath, i)
 
                     try:
                         data = role[config]
@@ -299,16 +278,6 @@ class Config(object):
 
         role_config = self.get_role_config()
         for config_name, config in six.iteritems(role_config):
-
-            # External tasks are in RoleConfig and not defined per role.
-            # So we don't use the RoleData to create the per step playbooks.
-            if config_name in constants.EXTERNAL_TASKS:
-                for i in range(constants.DEFAULT_STEPS_MAX):
-                    filepath = os.path.join(config_dir,
-                                            '%s_step%s.yaml'
-                                            % (config_name, i))
-                    self._write_tasks_per_step(config, filepath, i)
-
             conf_path = os.path.join(config_dir, config_name)
             # Add .yaml extension only if there's no extension already
             if '.' not in conf_path:
