@@ -17,6 +17,11 @@ from six.moves import urllib
 from tripleo_common import constants
 from tripleo_common.utils import common as common_utils
 
+try:  # py3
+    from shlex import quote
+except ImportError:  # py2
+    from pipes import quote
+
 
 def get_service_ips(stack):
     service_ips = {}
@@ -75,8 +80,6 @@ def create_overcloudrc(stack, no_proxy, admin_password, region_name):
                         [no_proxy, overcloud_host, overcloud_admin_vip])
 
     rc_params = {
-        'NOVA_VERSION': '1.1',
-        'COMPUTE_API_VERSION': '1.1',
         'OS_USERNAME': 'admin',
         'OS_PROJECT_NAME': 'admin',
         'OS_USER_DOMAIN_NAME': 'Default',
@@ -84,13 +87,13 @@ def create_overcloudrc(stack, no_proxy, admin_password, region_name):
         'OS_NO_CACHE': 'True',
         'OS_CLOUDNAME': stack.stack_name,
         'no_proxy': ','.join(no_proxy_list),
-        'PYTHONWARNINGS': ('"ignore:Certificate has no, ignore:A true '
-                           'SSLContext object is not available"'),
+        'PYTHONWARNINGS': ('ignore:Certificate has no, ignore:A true '
+                           'SSLContext object is not available'),
         'OS_AUTH_TYPE': 'password',
         'OS_PASSWORD': admin_password,
         'OS_AUTH_URL': overcloud_endpoint.replace('/v2.0', ''),
-        'OS_IDENTITY_API_VERSION': '3',
-        'OS_COMPUTE_API_VERSION': '2.latest',
+        'OS_IDENTITY_API_VERSION': constants.DEFAULT_IDENTITY_API_VERSION,
+        'OS_COMPUTE_API_VERSION': constants.DEFAULT_COMPUTE_API_VERSION,
         'OS_IMAGE_API_VERSION': constants.DEFAULT_IMAGE_API_VERSION,
         'OS_VOLUME_API_VERSION': constants.DEFAULT_VOLUME_API_VERSION,
         'OS_REGION_NAME': region_name or 'regionOne'
@@ -98,7 +101,8 @@ def create_overcloudrc(stack, no_proxy, admin_password, region_name):
 
     overcloudrc = CLEAR_ENV
     for key, value in rc_params.items():
-        line = "export %(key)s=%(value)s\n" % {'key': key, 'value': value}
+        line = "export %(key)s=%(value)s\n" % {'key': key,
+                                               'value': quote(value)}
         overcloudrc = overcloudrc + line
     overcloudrc = overcloudrc + CLOUDPROMPT
 
